Contribution Guidelines — Fedimg 1.3.0 documentation

# Contribution Guidelines

Fedimg welcomes contributors of all levels. Still, it can be a tricky project to jump into because of its relative youth and the challenge of testing a project that utilizes 3rd party services like AWS. This document hopes to alleviate confusion and encourage potential contributors.

## Communicating with other contributors

Communication with other contributors is crucial. The best way to discuss Fedimg development is by joining `#fedora-cloud` or `#fedora-apps` on the Freenode IRC network. For questions about the Fedora Infrastructure machines on which Fedimg runs, or about related fedmsg, your best bet is to say something in `#fedora-apps`.

You can also an email to the infrastructure mailing list.

## Submitting changes

Fedimg is uses Git and is hosted on GitHub. If you’ve managed to improve Fedimg in some way, make sure to open a pull requests at github.com/fedora-infra/fedimg, or you may e-email a patch to the infrastructure mailing list.